@@ -7,8 +7,9 @@ from unittest import mock
 
 import pytest
 from PIL import Image
-from pytesseract import TesseractError
+from pytest_mock import MockFixture
 from unstructured_inference.inference import layout
+from unstructured_pytesseract import TesseractError
 
 from test_unstructured.partition.pdf_image.test_pdf import assert_element_extraction
 from test_unstructured.unit_utils import assert_round_trips_through_JSON, example_doc_path
@@ -91,7 +92,7 @@ class MockDocumentLayout(layout.DocumentLayout):
 @pytest.mark.parametrize(
     ("filename", "file"),
     [
-        ("example-docs/example.jpg", None),
+        (example_doc_path("img/example.jpg"), None),
         (None, b"0000"),
     ],
 )
@@ -132,7 +133,7 @@ def test_partition_image_local_raises_with_no_filename():
 
 
 def test_partition_image_with_auto_strategy(
-    filename="example-docs/layout-parser-paper-fast.jpg",
+    filename=example_doc_path("img/layout-parser-paper-fast.jpg"),
 ):
     elements = image.partition_image(filename=filename, strategy=PartitionStrategy.AUTO)
     titles = [
@@ -146,7 +147,7 @@ def test_partition_image_with_auto_strategy(
 
 
 def test_partition_image_with_table_extraction(
-    filename="example-docs/layout-parser-paper-with-table.jpg",
+    filename=example_doc_path("img/layout-parser-paper-with-table.jpg"),
 ):
     elements = image.partition_image(
         filename=filename,
@@ -160,7 +161,7 @@ def test_partition_image_with_table_extraction(
 
 
 def test_partition_image_with_multipage_tiff(
-    filename="example-docs/layout-parser-paper-combined.tiff",
+    filename=example_doc_path("img/layout-parser-paper-combined.tiff"),
 ):
     elements = image.partition_image(filename=filename, strategy=PartitionStrategy.AUTO)
     assert elements[-1].metadata.page_number == 2
@@ -168,7 +169,7 @@ def test_partition_image_with_multipage_tiff(
 
 def test_partition_image_with_bmp(
     tmpdir,
-    filename="example-docs/layout-parser-paper-with-table.jpg",
+    filename=example_doc_path("img/layout-parser-paper-with-table.jpg"),
 ):
     bmp_filename = os.path.join(tmpdir.dirname, "example.bmp")
     img = Image.open(filename)
@@ -185,7 +186,7 @@ def test_partition_image_with_bmp(
     assert "</thead><tbody><tr>" in table[0]
 
 
-def test_partition_image_with_language_passed(filename="example-docs/example.jpg"):
+def test_partition_image_with_language_passed(filename=example_doc_path("img/example.jpg")):
     with mock.patch.object(
         ocr,
         "process_file_with_ocr",
@@ -201,7 +202,7 @@ def test_partition_image_with_language_passed(filename="example-docs/example.jpg
 
 
 def test_partition_image_from_file_with_language_passed(
-    filename="example-docs/example.jpg",
+    filename=example_doc_path("img/example.jpg"),
 ):
     with mock.patch.object(
         ocr,
@@ -216,7 +217,7 @@ def test_partition_image_from_file_with_language_passed(
 # NOTE(crag): see https://github.com/Unstructured-IO/unstructured/issues/1086
 @pytest.mark.skip(reason="Current catching too many tesseract errors")
 def test_partition_image_raises_with_invalid_language(
-    filename="example-docs/example.jpg",
+    filename=example_doc_path("img/example.jpg"),
 ):
     with pytest.raises(TesseractError):
         image.partition_image(
@@ -227,21 +228,14 @@ def test_partition_image_raises_with_invalid_language(
 
 
 @pytest.mark.parametrize(
-    ("strategy"),
+    "strategy",
     [
-        (PartitionStrategy.HI_RES),
-        (PartitionStrategy.OCR_ONLY),
+        PartitionStrategy.HI_RES,
+        PartitionStrategy.OCR_ONLY,
     ],
 )
 def test_partition_image_strategies_keep_languages_metadata(strategy):
-    filename = os.path.join(
-        DIRECTORY,
-        "..",
-        "..",
-        "..",
-        "example-docs",
-        "english-and-korean.png",
-    )
+    filename = example_doc_path("img/english-and-korean.png")
     elements = image.partition_image(
         filename=filename,
         languages=["eng", "kor"],
@@ -252,14 +246,7 @@ def test_partition_image_strategies_keep_languages_metadata(strategy):
 
 
 def test_partition_image_with_ocr_detects_korean():
-    filename = os.path.join(
-        DIRECTORY,
-        "..",
-        "..",
-        "..",
-        "example-docs",
-        "english-and-korean.png",
-    )
+    filename = example_doc_path("img/english-and-korean.png")
     elements = image.partition_image(
         filename=filename,
         ocr_languages="eng+kor",
@@ -271,7 +258,7 @@ def test_partition_image_with_ocr_detects_korean():
 
 
 def test_partition_image_with_ocr_detects_korean_from_file():
-    filename = os.path.join(DIRECTORY, "..", "..", "..", "example-docs", "english-and-korean.png")
+    filename = example_doc_path("img/english-and-korean.png")
     with open(filename, "rb") as f:
         elements = image.partition_image(
             file=f,
@@ -284,27 +271,13 @@ def test_partition_image_with_ocr_detects_korean_from_file():
 
 
 def test_partition_image_raises_with_bad_strategy():
-    filename = os.path.join(
-        DIRECTORY,
-        "..",
-        "..",
-        "..",
-        "example-docs",
-        "english-and-korean.png",
-    )
+    filename = example_doc_path("img/english-and-korean.png")
     with pytest.raises(ValueError):
         image.partition_image(filename=filename, strategy="fakeroo")
 
 
 def test_partition_image_default_strategy_hi_res():
-    filename = os.path.join(
-        DIRECTORY,
-        "..",
-        "..",
-        "..",
-        "example-docs",
-        "layout-parser-paper-fast.jpg",
-    )
+    filename = example_doc_path("img/layout-parser-paper-fast.jpg")
     with open(filename, "rb") as f:
         elements = image.partition_image(file=f)
 
@@ -322,201 +295,123 @@ def test_partition_image_default_strategy_hi_res():
         }
 
 
-def test_partition_image_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
-):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
+# -- .metadata.last_modified ---------------------------------------------------------------------
+
+
+def test_partition_image_from_file_path_gets_last_modified_from_filesystem(mocker: MockFixture):
+    filesystem_last_modified = "2029-07-05T09:24:28"
     mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date",
-        return_value=mocked_last_modification_date,
+        "unstructured.partition.pdf.get_last_modified_date",
+        return_value=filesystem_last_modified,
     )
-    elements = image.partition_image(filename=filename)
 
-    assert elements[0].metadata.last_modified == mocked_last_modification_date
+    elements = image.partition_image(example_doc_path("img/english-and-korean.png"))
+
+    assert all(e.metadata.last_modified == filesystem_last_modified for e in elements)
 
 
-def test_partition_image_with_hi_res_strategy_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
+def test_partition_image_from_file_path_with_hi_res_strategy_gets_last_modified_from_filesystem(
+    mocker: MockFixture,
 ):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
+    filesystem_last_modified = "2029-07-05T09:24:28"
     mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date",
-        return_value=mocked_last_modification_date,
+        "unstructured.partition.pdf.get_last_modified_date",
+        return_value=filesystem_last_modified,
     )
-    elements = image.partition_image(filename=filename, strategy=PartitionStrategy.HI_RES)
 
-    assert elements[0].metadata.last_modified == mocked_last_modification_date
-
-
-def test_partition_image_metadata_date_custom_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
-):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
-    expected_last_modification_date = "2009-07-05T09:24:28"
-
-    mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date",
-        return_value=mocked_last_modification_date,
-    )
     elements = image.partition_image(
-        filename=filename,
-        metadata_last_modified=expected_last_modification_date,
+        example_doc_path("img/english-and-korean.png"), strategy=PartitionStrategy.HI_RES
     )
 
-    assert elements[0].metadata.last_modified == expected_last_modification_date
+    assert all(e.metadata.last_modified == filesystem_last_modified for e in elements)
 
 
-def test_partition_image_with_hi_res_strategy_metadata_date_custom_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
-):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
-    expected_last_modification_date = "2009-07-05T09:24:28"
-
+def test_partition_image_from_file_path_prefers_metadata_last_modified(mocker: MockFixture):
+    filesystem_last_modified = "2029-07-05T09:24:28"
+    metadata_last_modified = "2009-07-05T09:24:28"
     mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date",
-        return_value=mocked_last_modification_date,
+        "unstructured.partition.pdf.get_last_modified_date",
+        return_value=filesystem_last_modified,
     )
+
     elements = image.partition_image(
-        filename=filename,
+        example_doc_path("img/english-and-korean.png"),
+        metadata_last_modified=metadata_last_modified,
+    )
+
+    assert all(e.metadata.last_modified == metadata_last_modified for e in elements)
+
+
+def test_partition_image_from_file_path_with_hi_res_strategy_prefers_metadata_last_modified(
+    mocker: MockFixture,
+):
+    filesystem_last_modified = "2029-07-05T09:24:28"
+    metadata_last_modified = "2009-07-05T09:24:28"
+    mocker.patch(
+        "unstructured.partition.pdf.get_last_modified_date",
+        return_value=filesystem_last_modified,
+    )
+
+    elements = image.partition_image(
+        example_doc_path("img/english-and-korean.png"),
         strategy=PartitionStrategy.HI_RES,
-        metadata_last_modified=expected_last_modification_date,
+        metadata_last_modified=metadata_last_modified,
     )
 
-    assert elements[0].metadata.last_modified == expected_last_modification_date
+    assert all(e.metadata.last_modified == metadata_last_modified for e in elements)
 
 
-def test_partition_image_from_file_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
-):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
-    mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date_from_file",
-        return_value=mocked_last_modification_date,
-    )
-    with open(filename, "rb") as f:
+def test_partition_image_from_file_gets_last_modified_None():
+    with open(example_doc_path("img/english-and-korean.png"), "rb") as f:
         elements = image.partition_image(file=f)
 
-    assert elements[0].metadata.last_modified is None
+    assert all(e.metadata.last_modified is None for e in elements)
 
 
-def test_partition_image_from_file_explicit_get_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
+def test_partition_image_from_file_with_hi_res_strategy_gets_last_modified_None(
+    mocker: MockFixture,
 ):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
-    mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date_from_file",
-        return_value=mocked_last_modification_date,
-    )
-    with open(filename, "rb") as f:
-        elements = image.partition_image(file=f, date_from_file_object=True)
-
-    assert elements[0].metadata.last_modified == mocked_last_modification_date
-
-
-def test_partition_image_from_file_with_hi_res_strategy_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
-):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
-    mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date_from_file",
-        return_value=mocked_last_modification_date,
-    )
-
-    with open(filename, "rb") as f:
+    with open(example_doc_path("img/english-and-korean.png"), "rb") as f:
         elements = image.partition_image(file=f, strategy=PartitionStrategy.HI_RES)
 
-    assert elements[0].metadata.last_modified is None
+    assert all(e.metadata.last_modified is None for e in elements)
 
 
-def test_partition_image_from_file_with_hi_res_strategy_explicit_get_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
-):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
-    mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date_from_file",
-        return_value=mocked_last_modification_date,
-    )
+def test_partition_image_from_file_prefers_metadata_last_modified():
+    metadata_last_modified = "2009-07-05T09:24:28"
 
-    with open(filename, "rb") as f:
-        elements = image.partition_image(
-            file=f, strategy=PartitionStrategy.HI_RES, date_from_file_object=True
-        )
+    with open(example_doc_path("img/english-and-korean.png"), "rb") as f:
+        elements = image.partition_image(file=f, metadata_last_modified=metadata_last_modified)
 
-    assert elements[0].metadata.last_modified == mocked_last_modification_date
+    assert all(e.metadata.last_modified == metadata_last_modified for e in elements)
 
 
-def test_partition_image_from_file_metadata_date_custom_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
-):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
-    expected_last_modification_date = "2009-07-05T09:24:28"
+def test_partition_image_from_file_with_hi_res_strategy_prefers_metadata_last_modified():
+    metadata_last_modified = "2009-07-05T09:24:28"
 
-    mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date_from_file",
-        return_value=mocked_last_modification_date,
-    )
-    with open(filename, "rb") as f:
+    with open(example_doc_path("img/english-and-korean.png"), "rb") as f:
         elements = image.partition_image(
             file=f,
-            metadata_last_modified=expected_last_modification_date,
-        )
-
-    assert elements[0].metadata.last_modified == expected_last_modification_date
-
-
-def test_partition_image_from_file_with_hi_res_strategy_metadata_date_custom_metadata_date(
-    mocker,
-    filename="example-docs/english-and-korean.png",
-):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
-    expected_last_modification_date = "2009-07-05T09:24:28"
-
-    mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date_from_file",
-        return_value=mocked_last_modification_date,
-    )
-    with open(filename, "rb") as f:
-        elements = image.partition_image(
-            file=f,
-            metadata_last_modified=expected_last_modification_date,
+            metadata_last_modified=metadata_last_modified,
             strategy=PartitionStrategy.HI_RES,
         )
 
-    assert elements[0].metadata.last_modified == expected_last_modification_date
+    assert all(e.metadata.last_modified == metadata_last_modified for e in elements)
 
 
-def test_partition_image_from_file_without_metadata_date(
-    filename="example-docs/english-and-korean.png",
-):
-    """Test partition_image() with file that are not possible to get last modified date"""
-    with open(filename, "rb") as f:
-        sf = tempfile.SpooledTemporaryFile()
-        sf.write(f.read())
-        sf.seek(0)
-        elements = image.partition_image(file=sf, date_from_file_object=True)
-
-    assert elements[0].metadata.last_modified is None
+# ------------------------------------------------------------------------------------------------
 
 
 def test_partition_msg_with_json():
     elements = image.partition_image(
-        example_doc_path("layout-parser-paper-fast.jpg"),
+        example_doc_path("img/layout-parser-paper-fast.jpg"),
         strategy=PartitionStrategy.AUTO,
     )
     assert_round_trips_through_JSON(elements)
 
 
 def test_partition_image_with_ocr_has_coordinates_from_filename(
-    filename="example-docs/english-and-korean.png",
+    filename=example_doc_path("img/english-and-korean.png"),
 ):
     elements = image.partition_image(filename=filename, strategy=PartitionStrategy.OCR_ONLY)
     int_coordinates = [(int(x), int(y)) for x, y in elements[0].metadata.coordinates.points]
@@ -524,11 +419,11 @@ def test_partition_image_with_ocr_has_coordinates_from_filename(
 
 
 @pytest.mark.parametrize(
-    ("filename"),
+    "filename",
     [
-        ("example-docs/layout-parser-paper-with-table.jpg"),
-        ("example-docs/english-and-korean.png"),
-        ("example-docs/layout-parser-paper-fast.jpg"),
+        "img/layout-parser-paper-with-table.jpg",
+        "img/english-and-korean.png",
+        "img/layout-parser-paper-fast.jpg",
     ],
 )
 def test_partition_image_with_ocr_coordinates_are_not_nan_from_filename(
@@ -536,7 +431,9 @@ def test_partition_image_with_ocr_coordinates_are_not_nan_from_filename(
 ):
     import math
 
-    elements = image.partition_image(filename=filename, strategy=PartitionStrategy.OCR_ONLY)
+    elements = image.partition_image(
+        filename=example_doc_path(filename), strategy=PartitionStrategy.OCR_ONLY
+    )
     for element in elements:
         # TODO (jennings) One or multiple elements is an empty string
         # without coordinates. This should be fixed in a new issue
@@ -548,7 +445,7 @@ def test_partition_image_with_ocr_coordinates_are_not_nan_from_filename(
 
 
 def test_partition_image_formats_languages_for_tesseract():
-    filename = "example-docs/jpn-vert.jpeg"
+    filename = example_doc_path("img/jpn-vert.jpeg")
     with mock.patch(
         "unstructured.partition.pdf_image.ocr.process_file_with_ocr",
     ) as mock_process_file_with_ocr:
@@ -561,13 +458,13 @@ def test_partition_image_formats_languages_for_tesseract():
 
 
 def test_partition_image_warns_with_ocr_languages(caplog):
-    filename = "example-docs/layout-parser-paper-fast.jpg"
+    filename = example_doc_path("img/layout-parser-paper-fast.jpg")
     image.partition_image(filename=filename, strategy=PartitionStrategy.HI_RES, ocr_languages="eng")
     assert "The ocr_languages kwarg will be deprecated" in caplog.text
 
 
 def test_add_chunking_strategy_on_partition_image(
-    filename="example-docs/layout-parser-paper-fast.jpg",
+    filename=example_doc_path("img/layout-parser-paper-fast.jpg"),
 ):
     elements = image.partition_image(filename=filename)
     chunk_elements = image.partition_image(filename, chunking_strategy="by_title")
@@ -577,7 +474,7 @@ def test_add_chunking_strategy_on_partition_image(
 
 
 def test_add_chunking_strategy_on_partition_image_hi_res(
-    filename="example-docs/layout-parser-paper-with-table.jpg",
+    filename=example_doc_path("img/layout-parser-paper-with-table.jpg"),
 ):
     elements = image.partition_image(
         filename=filename,
@@ -600,7 +497,9 @@ def test_partition_image_uses_model_name():
         pdf,
         "_partition_pdf_or_image_local",
     ) as mockpartition:
-        image.partition_image("example-docs/layout-parser-paper-fast.jpg", model_name="test")
+        image.partition_image(
+            example_doc_path("img/layout-parser-paper-fast.jpg"), model_name="test"
+        )
         print(mockpartition.call_args)
         assert "model_name" in mockpartition.call_args.kwargs
         assert mockpartition.call_args.kwargs["model_name"]
@@ -611,7 +510,9 @@ def test_partition_image_uses_hi_res_model_name():
         pdf,
         "_partition_pdf_or_image_local",
     ) as mockpartition:
-        image.partition_image("example-docs/layout-parser-paper-fast.jpg", hi_res_model_name="test")
+        image.partition_image(
+            example_doc_path("img/layout-parser-paper-fast.jpg"), hi_res_model_name="test"
+        )
         print(mockpartition.call_args)
         assert "model_name" not in mockpartition.call_args.kwargs
         assert "hi_res_model_name" in mockpartition.call_args.kwargs
@@ -626,7 +527,7 @@ def test_partition_image_uses_hi_res_model_name():
     ],
 )
 def test_partition_image_hi_res_ocr_mode(ocr_mode, idx_title_element):
-    filename = "example-docs/layout-parser-paper-fast.jpg"
+    filename = example_doc_path("img/layout-parser-paper-fast.jpg")
     elements = image.partition_image(
         filename=filename, ocr_mode=ocr_mode, strategy=PartitionStrategy.HI_RES
     )
@@ -635,7 +536,7 @@ def test_partition_image_hi_res_ocr_mode(ocr_mode, idx_title_element):
 
 
 def test_partition_image_hi_res_invalid_ocr_mode():
-    filename = "example-docs/layout-parser-paper-fast.jpg"
+    filename = example_doc_path("img/layout-parser-paper-fast.jpg")
     with pytest.raises(ValueError):
         _ = image.partition_image(
             filename=filename, ocr_mode="invalid_ocr_mode", strategy=PartitionStrategy.HI_RES
@@ -643,14 +544,14 @@ def test_partition_image_hi_res_invalid_ocr_mode():
 
 
 @pytest.mark.parametrize(
-    ("ocr_mode"),
+    "ocr_mode",
     [
-        ("entire_page"),
-        ("individual_blocks"),
+        "entire_page",
+        "individual_blocks",
     ],
 )
 def test_partition_image_hi_res_ocr_mode_with_table_extraction(ocr_mode):
-    filename = "example-docs/layout-parser-paper-with-table.jpg"
+    filename = example_doc_path("img/layout-parser-paper-with-table.jpg")
     elements = image.partition_image(
         filename=filename,
         ocr_mode=ocr_mode,
@@ -665,8 +566,8 @@ def test_partition_image_hi_res_ocr_mode_with_table_extraction(ocr_mode):
     assert "Layouts of scanned modern magazines and scientific reports" in table[0]
 
 
-def test_partition_image_raises_TypeError_for_invalid_languages():
-    filename = "example-docs/layout-parser-paper-fast.jpg"
+def test_partition_image_raises_type_error_for_invalid_languages():
+    filename = example_doc_path("img/layout-parser-paper-fast.jpg")
     with pytest.raises(TypeError):
         image.partition_image(filename=filename, strategy=PartitionStrategy.HI_RES, languages="eng")
 
@@ -683,7 +584,6 @@ def inference_results():
 
 
 def test_partition_image_has_filename(inference_results):
-    doc_path = "example-docs"
     filename = "layout-parser-paper-fast.jpg"
     # Mock inference call with known return results
     with mock.patch(
@@ -691,7 +591,7 @@ def test_partition_image_has_filename(inference_results):
         return_value=inference_results,
     ) as mock_inference_func:
         elements = image.partition_image(
-            filename=os.path.join(doc_path, filename),
+            filename=example_doc_path(f"img/{filename}"),
             strategy=PartitionStrategy.HI_RES,
         )
     # Make sure we actually went down the path we expect.
@@ -710,7 +610,7 @@ def test_partition_image_has_filename(inference_results):
 def test_partition_image_element_extraction(
     file_mode,
     extract_image_block_to_payload,
-    filename=example_doc_path("embedded-images-tables.jpg"),
+    filename=example_doc_path("img/embedded-images-tables.jpg"),
 ):
     extract_image_block_types = ["Image", "Table"]
 
@@ -737,7 +637,7 @@ def test_partition_image_element_extraction(
 
 
 def test_partition_image_works_on_heic_file(
-    filename="example-docs/DA-1p.heic",
+    filename=example_doc_path("img/DA-1p.heic"),
 ):
     elements = image.partition_image(filename=filename, strategy=PartitionStrategy.AUTO)
     titles = [el.text for el in elements if el.category == ElementType.TITLE]
@@ -745,17 +645,17 @@ def test_partition_image_works_on_heic_file(
 
 
 @pytest.mark.parametrize(
-    ("strategy"),
+    "strategy",
     [PartitionStrategy.HI_RES, PartitionStrategy.OCR_ONLY],
 )
 def test_deterministic_element_ids(strategy: str):
     elements_1 = image.partition_image(
-        example_doc_path("layout-parser-paper-with-table.jpg"),
+        example_doc_path("img/layout-parser-paper-with-table.jpg"),
         strategy=strategy,
         starting_page_number=2,
     )
     elements_2 = image.partition_image(
-        example_doc_path("layout-parser-paper-with-table.jpg"),
+        example_doc_path("img/layout-parser-paper-with-table.jpg"),
         strategy=strategy,
         starting_page_number=2,
     )
@@ -765,9 +665,9 @@ def test_deterministic_element_ids(strategy: str):
     assert ids_1 == ids_2
 
 
-def test_multipage_tiff_starts_on_starting_page_number():
+def test_multi_page_tiff_starts_on_starting_page_number():
     elements = image.partition_image(
-        example_doc_path("layout-parser-paper-combined.tiff"),
+        example_doc_path("img/layout-parser-paper-combined.tiff"),
         starting_page_number=2,
     )
     pages = {element.metadata.page_number for element in elements}
