@@ -12,6 +12,7 @@ from unittest import mock
 import pytest
 from pdf2image.exceptions import PDFPageCountError
 from PIL import Image
+from pytest_mock import MockFixture
 from unstructured_inference.inference import layout
 
 from test_unstructured.unit_utils import assert_round_trips_through_JSON, example_doc_path
@@ -29,6 +30,7 @@ from unstructured.documents.elements import (
     Text,
     Title,
 )
+from unstructured.errors import PageCountExceededError
 from unstructured.partition import pdf, strategies
 from unstructured.partition.pdf import get_uris_from_annots
 from unstructured.partition.pdf_image import ocr, pdfminer_processing
@@ -105,7 +107,7 @@ class MockDocumentLayout(layout.DocumentLayout):
 @pytest.mark.parametrize(
     ("filename", "file"),
     [
-        (example_doc_path("layout-parser-paper-fast.pdf"), None),
+        (example_doc_path("pdf/layout-parser-paper-fast.pdf"), None),
         (None, b"0000"),
     ],
 )
@@ -158,7 +160,7 @@ def test_partition_pdf_local_raises_with_no_filename():
     [
         (PartitionStrategy.FAST, 1, {1, 4}, {"pdfminer"}),
         (PartitionStrategy.FAST, 3, {3, 6}, {"pdfminer"}),
-        (PartitionStrategy.HI_RES, 4, {4, 6, 7}, {"yolox", "pdfminer"}),
+        (PartitionStrategy.HI_RES, 4, {4, 6, 7}, {"yolox", "pdfminer", "ocr_tesseract"}),
         (PartitionStrategy.OCR_ONLY, 1, {1, 3, 4}, {"ocr_tesseract"}),
     ],
 )
@@ -168,7 +170,7 @@ def test_partition_pdf_outputs_valid_amount_of_elements_and_metadata_values(
     starting_page_number,
     expected_page_numbers,
     origin,
-    filename=example_doc_path("layout-parser-paper-with-empty-pages.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-with-empty-pages.pdf"),
 ):
     # Test that the partition_pdf function can handle filename
     def _test(result):
@@ -177,6 +179,12 @@ def test_partition_pdf_outputs_valid_amount_of_elements_and_metadata_values(
         # check that the pdf has multiple different page numbers
         assert {element.metadata.page_number for element in result} == expected_page_numbers
         if UNSTRUCTURED_INCLUDE_DEBUG_METADATA:
+            print(
+                [
+                    (element.metadata.detection_origin, element.category, element.text)
+                    for element in result
+                ]
+            )
             assert {element.metadata.detection_origin for element in result} == origin
 
     if file_mode == "filename":
@@ -204,7 +212,7 @@ def test_partition_pdf_outputs_valid_amount_of_elements_and_metadata_values(
 @mock.patch.dict(os.environ, {"UNSTRUCTURED_HI_RES_MODEL_NAME": "checkbox"})
 def test_partition_pdf_with_model_name_env_var(
     monkeypatch,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     monkeypatch.setattr(pdf, "extractable_elements", lambda *args, **kwargs: [])
     with mock.patch.object(
@@ -216,11 +224,11 @@ def test_partition_pdf_with_model_name_env_var(
         assert mock_process.call_args[1]["model_name"] == "checkbox"
 
 
-@pytest.mark.parametrize("model_name", ["checkbox", "yolox", "chipper"])
+@pytest.mark.parametrize("model_name", ["checkbox", "yolox"])
 def test_partition_pdf_with_model_name(
     monkeypatch,
     model_name,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     monkeypatch.setattr(pdf, "extractable_elements", lambda *args, **kwargs: [])
     with mock.patch.object(
@@ -251,7 +259,7 @@ def test_partition_pdf_with_model_name(
 
 def test_partition_pdf_with_hi_res_model_name(
     monkeypatch,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     monkeypatch.setattr(pdf, "extractable_elements", lambda *args, **kwargs: [])
     with mock.patch.object(
@@ -268,7 +276,7 @@ def test_partition_pdf_with_hi_res_model_name(
 
 def test_partition_pdf_or_image_with_hi_res_model_name(
     monkeypatch,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     monkeypatch.setattr(pdf, "extractable_elements", lambda *args, **kwargs: [])
     with mock.patch.object(
@@ -284,7 +292,7 @@ def test_partition_pdf_or_image_with_hi_res_model_name(
 
 
 def test_partition_pdf_with_auto_strategy(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     elements = pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.AUTO)
     title = "LayoutParser: A Uniﬁed Toolkit for Deep Learning Based Document Image Analysis"
@@ -294,21 +302,21 @@ def test_partition_pdf_with_auto_strategy(
 
 
 def test_partition_pdf_with_page_breaks(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     elements = pdf.partition_pdf(filename=filename, url=None, include_page_breaks=True)
     assert "PageBreak" in [elem.category for elem in elements]
 
 
 def test_partition_pdf_with_no_page_breaks(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     elements = pdf.partition_pdf(filename=filename, url=None)
     assert "PageBreak" not in [elem.category for elem in elements]
 
 
 def test_partition_pdf_with_fast_strategy(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     elements = pdf.partition_pdf(
         filename=filename, url=None, strategy=PartitionStrategy.FAST, starting_page_number=3
@@ -321,7 +329,7 @@ def test_partition_pdf_with_fast_strategy(
 
 
 def test_partition_pdf_with_fast_neg_coordinates():
-    filename = example_doc_path("negative-coords.pdf")
+    filename = example_doc_path("pdf/negative-coords.pdf")
     elements = pdf.partition_pdf(filename=filename, url=None, strategy=PartitionStrategy.FAST)
     assert len(elements) == 5
     assert elements[0].metadata.coordinates.points[0][0] < 0
@@ -329,7 +337,7 @@ def test_partition_pdf_with_fast_neg_coordinates():
 
 
 def test_partition_pdf_with_fast_groups_text(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     elements = pdf.partition_pdf(filename=filename, url=None, strategy=PartitionStrategy.FAST)
 
@@ -345,7 +353,7 @@ def test_partition_pdf_with_fast_groups_text(
 
 
 def test_partition_pdf_with_fast_strategy_from_file(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     with open(filename, "rb") as f:
         elements = pdf.partition_pdf(file=f, url=None, strategy=PartitionStrategy.FAST)
@@ -354,7 +362,7 @@ def test_partition_pdf_with_fast_strategy_from_file(
 
 def test_partition_pdf_with_fast_strategy_and_page_breaks(
     caplog,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     elements = pdf.partition_pdf(
         filename=filename,
@@ -371,7 +379,7 @@ def test_partition_pdf_with_fast_strategy_and_page_breaks(
 
 
 def test_partition_pdf_raises_with_bad_strategy(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     with pytest.raises(ValueError):
         pdf.partition_pdf(filename=filename, url=None, strategy="made_up")
@@ -380,10 +388,10 @@ def test_partition_pdf_raises_with_bad_strategy(
 def test_partition_pdf_falls_back_to_fast(
     monkeypatch,
     caplog,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     def mock_exists(dep):
-        return dep not in ["unstructured_inference", "pytesseract"]
+        return dep not in ["unstructured_inference", "unstructured_pytesseract"]
 
     monkeypatch.setattr(strategies, "dependency_exists", mock_exists)
 
@@ -402,10 +410,10 @@ def test_partition_pdf_falls_back_to_fast(
 def test_partition_pdf_falls_back_to_fast_from_ocr_only(
     monkeypatch,
     caplog,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     def mock_exists(dep):
-        return dep not in ["pytesseract"]
+        return dep not in ["unstructured_pytesseract"]
 
     monkeypatch.setattr(strategies, "dependency_exists", mock_exists)
 
@@ -428,10 +436,10 @@ def test_partition_pdf_falls_back_to_fast_from_ocr_only(
 def test_partition_pdf_falls_back_to_hi_res_from_ocr_only(
     monkeypatch,
     caplog,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     def mock_exists(dep):
-        return dep not in ["pytesseract"]
+        return dep not in ["unstructured_pytesseract"]
 
     monkeypatch.setattr(strategies, "dependency_exists", mock_exists)
     monkeypatch.setattr(pdf, "extractable_elements", lambda *args, **kwargs: [])
@@ -451,7 +459,7 @@ def test_partition_pdf_falls_back_to_hi_res_from_ocr_only(
 def test_partition_pdf_falls_back_to_ocr_only(
     monkeypatch,
     caplog,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     def mock_exists(dep):
         return dep not in ["unstructured_inference"]
@@ -471,7 +479,7 @@ def test_partition_pdf_falls_back_to_ocr_only(
 
 
 def test_partition_pdf_uses_table_extraction():
-    filename = example_doc_path("layout-parser-paper-fast.pdf")
+    filename = example_doc_path("pdf/layout-parser-paper-fast.pdf")
     with mock.patch(
         "unstructured.partition.pdf_image.ocr.process_file_with_ocr",
     ) as mock_process_file_with_model:
@@ -480,14 +488,14 @@ def test_partition_pdf_uses_table_extraction():
 
 
 @pytest.mark.parametrize(
-    ("ocr_mode"),
+    "ocr_mode",
     [
-        ("entire_page"),
-        ("individual_blocks"),
+        "entire_page",
+        "individual_blocks",
     ],
 )
 def test_partition_pdf_hi_table_extraction_with_languages(ocr_mode):
-    filename = example_doc_path("korean-text-with-tables.pdf")
+    filename = example_doc_path("pdf/korean-text-with-tables.pdf")
     elements = pdf.partition_pdf(
         filename=filename,
         ocr_mode=ocr_mode,
@@ -506,15 +514,15 @@ def test_partition_pdf_hi_table_extraction_with_languages(ocr_mode):
 
 
 @pytest.mark.parametrize(
-    ("strategy"),
+    "strategy",
     [
-        (PartitionStrategy.FAST),
-        (PartitionStrategy.HI_RES),
-        (PartitionStrategy.OCR_ONLY),
+        PartitionStrategy.FAST,
+        PartitionStrategy.HI_RES,
+        PartitionStrategy.OCR_ONLY,
     ],
 )
 def test_partition_pdf_strategies_keep_languages_metadata(strategy):
-    filename = example_doc_path("korean-text-with-tables.pdf")
+    filename = example_doc_path("pdf/korean-text-with-tables.pdf")
     elements = pdf.partition_pdf(
         filename=filename,
         languages=["kor"],
@@ -531,7 +539,7 @@ def test_partition_pdf_strategies_keep_languages_metadata(strategy):
     ],
 )
 def test_partition_pdf_hi_res_ocr_mode_with_table_extraction(ocr_mode):
-    filename = example_doc_path("layout-parser-paper.pdf")
+    filename = example_doc_path("pdf/layout-parser-paper.pdf")
     elements = pdf.partition_pdf(
         filename=filename,
         ocr_mode=ocr_mode,
@@ -548,10 +556,10 @@ def test_partition_pdf_hi_res_ocr_mode_with_table_extraction(ocr_mode):
 
 
 def test_partition_pdf_with_copy_protection():
-    filename = os.path.join("example-docs", "copy-protected.pdf")
+    filename = example_doc_path("pdf/copy-protected.pdf")
     elements = pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.HI_RES)
     title = "LayoutParser: A Uniﬁed Toolkit for Deep Learning Based Document Image Analysis"
-    idx = 2
+    idx = 22
     assert elements[idx].text == title
     assert {element.metadata.page_number for element in elements} == {1, 2}
     assert elements[idx].metadata.detection_class_prob is not None
@@ -559,13 +567,13 @@ def test_partition_pdf_with_copy_protection():
 
 
 def test_partition_pdf_with_dpi():
-    filename = os.path.join("example-docs", "copy-protected.pdf")
+    filename = example_doc_path("pdf/copy-protected.pdf")
     with mock.patch.object(layout, "process_file_with_model", mock.MagicMock()) as mock_process:
         pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.HI_RES, pdf_image_dpi=100)
         assert mock_process.call_args[1]["pdf_image_dpi"] == 100
 
 
-def test_partition_pdf_requiring_recursive_text_grab(filename=example_doc_path("reliance.pdf")):
+def test_partition_pdf_requiring_recursive_text_grab(filename=example_doc_path("pdf/reliance.pdf")):
     elements = pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.FAST)
     assert len(elements) > 50
     assert elements[0].metadata.page_number == 1
@@ -573,17 +581,17 @@ def test_partition_pdf_requiring_recursive_text_grab(filename=example_doc_path("
 
 
 def test_partition_pdf_text_not_extractable():
-    filename = example_doc_path("loremipsum-flat.pdf")
+    filename = example_doc_path("pdf/loremipsum-flat.pdf")
     elements = pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.FAST)
     assert len(elements) == 0
 
 
 def test_partition_pdf_fails_if_pdf_not_processable(
     monkeypatch,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     def mock_exists(dep):
-        return dep not in ["unstructured_inference", "pytesseract"]
+        return dep not in ["unstructured_inference", "unstructured_pytesseract"]
 
     monkeypatch.setattr(strategies, "dependency_exists", mock_exists)
     monkeypatch.setattr(pdf, "extractable_elements", lambda *args, **kwargs: [])
@@ -593,7 +601,7 @@ def test_partition_pdf_fails_if_pdf_not_processable(
 
 
 def test_partition_pdf_fast_groups_text_in_text_box():
-    filename = os.path.join("example-docs", "chevron-page.pdf")
+    filename = example_doc_path("pdf/chevron-page.pdf")
     elements = pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.FAST)
     expected_coordinate_points_0 = (
         (193.1741, 71.94000000000005),
@@ -633,7 +641,7 @@ def test_partition_pdf_fast_groups_text_in_text_box():
 
 
 def test_partition_pdf_with_metadata_filename(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     elements = pdf.partition_pdf(
         filename=filename,
@@ -646,7 +654,7 @@ def test_partition_pdf_with_metadata_filename(
 
 
 def test_partition_pdf_with_fast_strategy_from_file_with_metadata_filename(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     with open(filename, "rb") as f:
         elements = pdf.partition_pdf(
@@ -659,40 +667,6 @@ def test_partition_pdf_with_fast_strategy_from_file_with_metadata_filename(
         assert element.metadata.filename == "test"
 
 
-@pytest.mark.parametrize("file_mode", ["filename", "rb"])
-@pytest.mark.parametrize(
-    "strategy",
-    [
-        PartitionStrategy.AUTO,
-        PartitionStrategy.HI_RES,
-        PartitionStrategy.FAST,
-        PartitionStrategy.OCR_ONLY,
-    ],
-)
-def test_partition_pdf_exclude_metadata(
-    file_mode,
-    strategy,
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
-):
-    if file_mode == "filename":
-        elements = pdf.partition_pdf(
-            filename=filename,
-            strategy=strategy,
-            include_metadata=False,
-        )
-    else:
-        with open(filename, "rb") as f:
-            elements = pdf.partition_pdf(
-                file=f,
-                url=None,
-                strategy=strategy,
-                include_metadata=False,
-            )
-
-    for i in range(len(elements)):
-        assert elements[i].metadata.to_dict() == {}
-
-
 @pytest.mark.parametrize("file_mode", ["filename", "rb", "spool"])
 @pytest.mark.parametrize(
     "strategy",
@@ -703,46 +677,38 @@ def test_partition_pdf_exclude_metadata(
         PartitionStrategy.OCR_ONLY,
     ],
 )
-@pytest.mark.parametrize("last_modification_date", [None, "2020-07-05T09:24:28"])
-@pytest.mark.parametrize("date_from_file_object", [True, False])
+@pytest.mark.parametrize("metadata_last_modified", [None, "2020-07-05T09:24:28"])
 def test_partition_pdf_metadata_date(
-    mocker,
-    file_mode,
-    strategy,
-    last_modification_date,
-    date_from_file_object,
-    filename=example_doc_path("copy-protected.pdf"),
+    mocker: MockFixture,
+    file_mode: str,
+    strategy: str,
+    metadata_last_modified: str | None,
 ):
-    mocked_last_modification_date = "2029-07-05T09:24:28"
-    expected_last_modification_date = (
-        last_modification_date if last_modification_date else mocked_last_modification_date
+    filename = example_doc_path("pdf/copy-protected.pdf")
+    filesystem_last_modified = "2029-07-05T09:24:28"
+    expected_last_modified = (
+        metadata_last_modified if metadata_last_modified else filesystem_last_modified
     )
-    if not date_from_file_object and not last_modification_date and file_mode != "filename":
-        expected_last_modification_date = None
+    if not metadata_last_modified and file_mode != "filename":
+        expected_last_modified = None
 
     mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date_from_file",
-        return_value=mocked_last_modification_date,
-    )
-    mocker.patch(
-        "unstructured.partition.pdf_image.pdf_image_utils.get_last_modified_date",
-        return_value=mocked_last_modification_date,
+        "unstructured.partition.pdf.get_last_modified_date",
+        return_value=filesystem_last_modified,
     )
 
     if file_mode == "filename":
         elements = pdf.partition_pdf(
             filename=filename,
             strategy=strategy,
-            metadata_last_modified=last_modification_date,
-            date_from_file_object=date_from_file_object,
+            metadata_last_modified=metadata_last_modified,
         )
     elif file_mode == "rb":
         with open(filename, "rb") as f:
             elements = pdf.partition_pdf(
                 file=f,
                 strategy=strategy,
-                metadata_last_modified=last_modification_date,
-                date_from_file_object=date_from_file_object,
+                metadata_last_modified=metadata_last_modified,
             )
     else:
         with open(filename, "rb") as test_file:
@@ -752,24 +718,23 @@ def test_partition_pdf_metadata_date(
             elements = pdf.partition_pdf(
                 file=spooled_temp_file,
                 strategy=strategy,
-                metadata_last_modified=last_modification_date,
-                date_from_file_object=date_from_file_object,
+                metadata_last_modified=metadata_last_modified,
             )
 
-    assert {el.metadata.last_modified for el in elements} == {expected_last_modification_date}
+    assert {el.metadata.last_modified for el in elements} == {expected_last_modified}
 
 
 @pytest.mark.parametrize("strategy", [PartitionStrategy.FAST, PartitionStrategy.HI_RES])
 def test_partition_pdf_with_json(strategy: str):
     elements = pdf.partition_pdf(
-        example_doc_path("layout-parser-paper-fast.pdf"),
+        example_doc_path("pdf/layout-parser-paper-fast.pdf"),
         strategy=strategy,
     )
     assert_round_trips_through_JSON(elements)
 
 
 def test_add_chunking_strategy_by_title_on_partition_pdf(
-    filename=example_doc_path("layout-parser-paper-fast.pdf"),
+    filename=example_doc_path("pdf/layout-parser-paper-fast.pdf"),
 ):
     elements = pdf.partition_pdf(filename=filename)
     chunk_elements = pdf.partition_pdf(filename, chunking_strategy="by_title")
@@ -779,14 +744,14 @@ def test_add_chunking_strategy_by_title_on_partition_pdf(
 
 
 def test_partition_pdf_formats_languages_for_tesseract():
-    filename = example_doc_path("DA-1p.pdf")
+    filename = example_doc_path("pdf/DA-1p.pdf")
     with mock.patch.object(ocr, "process_file_with_ocr", mock.MagicMock()) as mock_process:
         pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.HI_RES, languages=["en"])
         assert mock_process.call_args[1]["ocr_languages"] == "eng"
 
 
 def test_partition_pdf_warns_with_ocr_languages(caplog):
-    filename = example_doc_path("chevron-page.pdf")
+    filename = example_doc_path("pdf/chevron-page.pdf")
     pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.HI_RES, ocr_languages="eng")
     assert "The ocr_languages kwarg will be deprecated" in caplog.text
 
@@ -795,7 +760,7 @@ def test_partition_categorization_backup():
     text = "This is Clearly a Title"
     with mock.patch.object(pdf, "_partition_pdf_or_image_local", return_value=[Text(text)]):
         elements = pdf.partition_pdf_or_image(
-            example_doc_path("layout-parser-paper-fast.pdf"),
+            example_doc_path("pdf/layout-parser-paper-fast.pdf"),
             strategy=PartitionStrategy.HI_RES,
         )
         # Should have changed the element class from Text to Title
@@ -805,7 +770,7 @@ def test_partition_categorization_backup():
 
 @pytest.mark.parametrize(
     "filename",
-    [example_doc_path("layout-parser-paper-fast.pdf")],
+    [example_doc_path("pdf/layout-parser-paper-fast.pdf")],
 )
 def test_combine_numbered_list(filename):
     elements = pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.AUTO)
@@ -823,7 +788,7 @@ def test_combine_numbered_list(filename):
 
 @pytest.mark.parametrize(
     "filename",
-    [example_doc_path("layout-parser-paper-fast.pdf")],
+    [example_doc_path("pdf/layout-parser-paper-fast.pdf")],
 )
 def test_partition_pdf_hyperlinks(filename):
     elements = pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.AUTO)
@@ -849,7 +814,7 @@ def test_partition_pdf_hyperlinks(filename):
 
 @pytest.mark.parametrize(
     "filename",
-    [example_doc_path("embedded-link.pdf")],
+    [example_doc_path("pdf/embedded-link.pdf")],
 )
 def test_partition_pdf_hyperlinks_multiple_lines(filename):
     elements = pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.AUTO)
@@ -863,7 +828,7 @@ def test_partition_pdf_uses_model_name():
         "_partition_pdf_or_image_local",
     ) as mockpartition:
         pdf.partition_pdf(
-            example_doc_path("layout-parser-paper-fast.pdf"),
+            example_doc_path("pdf/layout-parser-paper-fast.pdf"),
             model_name="test",
             strategy=PartitionStrategy.HI_RES,
         )
@@ -879,7 +844,7 @@ def test_partition_pdf_uses_hi_res_model_name():
         "_partition_pdf_or_image_local",
     ) as mockpartition:
         pdf.partition_pdf(
-            example_doc_path("layout-parser-paper-fast.pdf"),
+            example_doc_path("pdf/layout-parser-paper-fast.pdf"),
             hi_res_model_name="test",
             strategy=PartitionStrategy.HI_RES,
         )
@@ -890,7 +855,7 @@ def test_partition_pdf_uses_hi_res_model_name():
 
 
 def test_partition_pdf_word_bbox_not_char(
-    filename=example_doc_path("interface-config-guide-p93.pdf"),
+    filename=example_doc_path("pdf/interface-config-guide-p93.pdf"),
 ):
     try:
         elements = pdf.partition_pdf(filename=filename, strategy="fast")
@@ -900,7 +865,7 @@ def test_partition_pdf_word_bbox_not_char(
 
 
 def test_partition_pdf_fast_no_mapping_errors(
-    filename=example_doc_path("a1977-backus-p21.pdf"),
+    filename=example_doc_path("pdf/a1977-backus-p21.pdf"),
 ):
     """Verify there is no regression for https://github.com/Unstructured-IO/unstructured/pull/2940,
     failing to map old parent_id's to new"""
@@ -908,7 +873,7 @@ def test_partition_pdf_fast_no_mapping_errors(
 
 
 def test_partition_pdf_raises_TypeError_for_invalid_languages():
-    filename = example_doc_path("chevron-page.pdf")
+    filename = example_doc_path("pdf/chevron-page.pdf")
     with pytest.raises(TypeError):
         pdf.partition_pdf(filename=filename, strategy=PartitionStrategy.HI_RES, languages="eng")
 
@@ -948,7 +913,7 @@ def test_default_hi_res_model(env, expected, monkeypatch):
 
 
 def test_partition_model_name_default_to_None():
-    filename = example_doc_path("DA-1p.pdf")
+    filename = example_doc_path("pdf/DA-1p.pdf")
     try:
         pdf.partition_pdf(
             filename=filename,
@@ -961,7 +926,7 @@ def test_partition_model_name_default_to_None():
 
 
 def test_partition_hi_res_model_name_default_to_None():
-    filename = example_doc_path("DA-1p.pdf")
+    filename = example_doc_path("pdf/DA-1p.pdf")
     try:
         pdf.partition_pdf(
             filename=filename,
@@ -998,7 +963,7 @@ def test_ocr_language_passes_through(strategy, ocr_func):
     # Patch the ocr function with the mock that will record the call and then terminate
     with mock.patch(ocr_func, mock_ocr_func), pytest.raises(CallException):
         pdf.partition_pdf(
-            example_doc_path("layout-parser-paper-fast.pdf"),
+            example_doc_path("pdf/layout-parser-paper-fast.pdf"),
             strategy=strategy,
             ocr_languages="kor",
         )
@@ -1089,8 +1054,8 @@ def test_get_uris_from_annots_string_annotation(
 @pytest.mark.parametrize(
     ("filename", "is_image"),
     [
-        (example_doc_path("layout-parser-paper-fast.pdf"), False),
-        (example_doc_path("layout-parser-paper-fast.jpg"), True),
+        (example_doc_path("pdf/layout-parser-paper-fast.pdf"), False),
+        (example_doc_path("img/layout-parser-paper-fast.jpg"), True),
     ],
 )
 def test_partition_pdf_with_ocr_only_strategy(
@@ -1148,18 +1113,20 @@ def test_partition_pdf_with_ocr_only_strategy(
 def test_partition_pdf_with_all_number_table_and_ocr_only_strategy():
     # AttributeError was previously being raised when partitioning documents that contained only
     # numerical values with `strategy=PartitionStrategy.OCR_ONLY`
-    filename = example_doc_path("all-number-table.pdf")
+    filename = example_doc_path("pdf/all-number-table.pdf")
     assert pdf.partition_pdf(filename, strategy=PartitionStrategy.OCR_ONLY)
 
 
 # As of pdfminer 221105, this pdf throws an error and requires a workaround
 # See #2059
 def test_partition_pdf_with_bad_color_profile():
-    filename = example_doc_path("pdf-bad-color-space.pdf")
+    filename = example_doc_path("pdf/pdf-bad-color-space.pdf")
     assert pdf.partition_pdf(filename, strategy="fast")
 
 
-def test_partition_pdf_with_fast_finds_headers_footers(filename="example-docs/header-test-doc.pdf"):
+def test_partition_pdf_with_fast_finds_headers_footers(
+    filename=example_doc_path("pdf/header-test-doc.pdf"),
+):
     elements = pdf.partition_pdf(filename, strategy="fast")
     assert isinstance(elements[0], Header)
     assert isinstance(elements[-1], Footer)
@@ -1180,7 +1147,7 @@ def test_partition_pdf_with_fast_finds_headers_footers(filename="example-docs/he
 )
 def test_extractable_elements_repair_invalid_pdf_structure(filename, expected_log, caplog):
     caplog.set_level(logging.INFO)
-    assert pdf.extractable_elements(filename=example_doc_path(filename))
+    assert pdf.extractable_elements(filename=example_doc_path(f"pdf/{filename}"))
     assert expected_log in caplog.text
 
 
@@ -1222,7 +1189,7 @@ def assert_element_extraction(
 def test_partition_pdf_element_extraction(
     file_mode,
     extract_image_block_to_payload,
-    filename=example_doc_path("embedded-images-tables.pdf"),
+    filename=example_doc_path("pdf/embedded-images-tables.pdf"),
 ):
     extract_image_block_types = ["Image", "Table"]
 
@@ -1253,7 +1220,7 @@ def test_partition_pdf_element_extraction(
 
 
 def test_partition_pdf_always_keep_all_image_elements(
-    filename=example_doc_path("embedded-images.pdf"),
+    filename=example_doc_path("pdf/embedded-images.pdf"),
 ):
     elements = pdf.partition_pdf(
         filename=filename,
@@ -1325,36 +1292,103 @@ def expected_ids(request):
 )
 def test_unique_and_deterministic_element_ids(strategy, expected_ids):
     elements = pdf.partition_pdf(
-        "example-docs/fake-memo-with-duplicate-page.pdf", strategy=strategy, starting_page_number=2
+        example_doc_path("pdf/fake-memo-with-duplicate-page.pdf"),
+        strategy=strategy,
+        starting_page_number=2,
     )
     ids = [element.id for element in elements]
     assert ids == expected_ids, "Element IDs do not match expected IDs"
 
 
-def test_analysis_artifacts_saved():
+@pytest.mark.parametrize("is_path", [True, False])
+@pytest.mark.parametrize(
+    ("example_doc", "doc_pages"),
+    [
+        ("pdf/layout-parser-paper-fast.pdf", 2),
+        ("img/DA-1p.png", 1),
+    ],
+)
+def test_analysis_artifacts_saved(is_path: bool, example_doc: str, doc_pages: int):
     with tempfile.TemporaryDirectory() as temp_dir:
-        filename = example_doc_path("layout-parser-paper-fast.pdf")
+        file = None
+        filename = example_doc_path(example_doc)
+        is_image = not Path(filename).suffix.endswith("pdf")
+        if not is_path:
+            file = open(filename, "rb")  # noqa: SIM115
+            filename = None
         pdf.partition_pdf(
             filename=filename,
+            file=file,
+            is_image=is_image,
             strategy=PartitionStrategy.HI_RES,
             analysis=True,
             analyzed_image_output_dir_path=temp_dir,
         )
 
         analysis_dir = Path(temp_dir)
-        layout_dump_dir = analysis_dir / "analysis" / "layout-parser-paper-fast" / "layout_dump"
+        file_analysis_root = None
+        if is_path:
+            file_analysis_root = analysis_dir / "analysis" / Path(example_doc).stem
+        else:
+            # if file is not a path, the filename is None and the analysis directory
+            # for the document is generated
+            generated_file_stem_path = list((analysis_dir / "analysis").iterdir())[0]
+            if is_image:
+                assert "image" in generated_file_stem_path.name
+            else:
+                assert "pdf" in generated_file_stem_path.name
+            file_analysis_root = generated_file_stem_path
+        layout_dump_dir = file_analysis_root / "layout_dump"
         assert layout_dump_dir.exists()
         layout_dump_files = list(layout_dump_dir.iterdir())
-        assert len(layout_dump_files) == 1
-        assert (layout_dump_dir / "object_detection.json").exists()
 
-        bboxes_dir = analysis_dir / "analysis" / "layout-parser-paper-fast" / "bboxes"
+        expected_layout_dumps = ["object_detection", "ocr", "pdfminer", "final"]
+        assert len(layout_dump_files) == len(expected_layout_dumps)
+
+        for expected_layout_dump in expected_layout_dumps:
+            assert (layout_dump_dir / f"{expected_layout_dump}.json").exists()
+
+        bboxes_dir = file_analysis_root / "bboxes"
         assert bboxes_dir.exists()
         bboxes_files = list(bboxes_dir.iterdir())
-        assert len(bboxes_files) == 2 * 4  # 2 pages * 4 different layouts per page
 
-        expected_layouts = ["od_model", "ocr", "pdfminer", "final"]
-        expected_pages = [1, 2]
-        for el in expected_layouts:
+        expected_renders = ["od_model", "ocr", "pdfminer", "final"]
+        assert len(bboxes_files) == doc_pages * len(expected_renders)
+
+        expected_pages = range(1, doc_pages + 1)
+        for el in expected_renders:
             for page in expected_pages:
                 assert bboxes_dir / f"page{page}_layout_{el}.png" in bboxes_files
+        if file:
+            file.close()
+
+
+@pytest.mark.parametrize(
+    ("filename", "pdf_hi_res_max_pages", "expected_error"),
+    [
+        ("pdf/layout-parser-paper-with-empty-pages.pdf", None, False),
+        ("pdf/layout-parser-paper-with-empty-pages.pdf", 3, True),
+        ("pdf/reliance.pdf", 3, False),
+        ("pdf/reliance.pdf", 2, True),
+        ("img/DA-1p.jpg", None, False),
+        ("img/DA-1p.jpg", 2, False),
+    ],
+)
+def test_pdf_hi_res_max_pages_argument(filename, pdf_hi_res_max_pages, expected_error):
+    is_image = not Path(filename).suffix.endswith("pdf")
+    if not expected_error:
+        pdf.partition_pdf_or_image(
+            filename=example_doc_path(filename),
+            strategy=PartitionStrategy.HI_RES,
+            pdf_hi_res_max_pages=pdf_hi_res_max_pages,
+            is_image=is_image,
+        )
+
+    else:
+        with pytest.raises(PageCountExceededError):
+            pdf.partition_pdf_or_image(
+                filename=example_doc_path(filename),
+                strategy=PartitionStrategy.HI_RES,
+                pdf_hi_res_max_pages=pdf_hi_res_max_pages,
+                is_image=is_image,
+            )
