@@ -4,21 +4,33 @@ import json
 import os
 import pathlib
 from typing import Any
+from unittest.mock import Mock
 
 import pytest
 import requests
 from unstructured_client.general import General
 from unstructured_client.models import shared
+from unstructured_client.models.operations import PartitionRequest
 from unstructured_client.models.shared import PartitionParameters
+from unstructured_client.utils import retries
 
 from unstructured.documents.elements import ElementType, NarrativeText
-from unstructured.partition.api import partition_multiple_via_api, partition_via_api
+from unstructured.partition.api import (
+    DEFAULT_RETRIES_MAX_ELAPSED_TIME_SEC,
+    DEFAULT_RETRIES_MAX_INTERVAL_SEC,
+    get_retries_config,
+    partition_multiple_via_api,
+    partition_via_api,
+)
 
 from ..unit_utils import ANY, FixtureRequest, example_doc_path, method_mock
 
 DIRECTORY = pathlib.Path(__file__).parent.resolve()
 
-skip_outside_ci = os.getenv("CI", "").lower() in {"", "false", "f", "0"}
+# NOTE(yao): point to paid API for now
+API_URL = "https://api.unstructuredapp.io/general/v0/general"
+
+is_in_ci = os.getenv("CI", "").lower() not in {"", "false", "f", "0"}
 skip_not_on_main = os.getenv("GITHUB_REF_NAME", "").lower() != "main"
 
 
@@ -52,7 +64,7 @@ def test_partition_via_api_with_file_correctly_calls_sdk(
 
     # Update the fixture content to match the format passed to partition_via_api
     modified_expected_call = expected_call_[:]
-    modified_expected_call[1].files.content = f
+    modified_expected_call[1].partition_parameters.files.content = f
 
     partition_mock_.assert_called_once_with(*modified_expected_call)
     assert isinstance(partition_mock_.call_args_list[0].args[0], General)
@@ -73,7 +85,7 @@ def test_partition_via_api_warns_with_file_and_filename_and_calls_sdk(
 
     # Update the fixture content to match the format passed to partition_via_api
     modified_expected_call = expected_call_[:]
-    modified_expected_call[1].files.content = f
+    modified_expected_call[1].partition_parameters.files.content = f
 
     partition_mock_.assert_called_once_with(*modified_expected_call)
     assert "WARNING" in caplog.text
@@ -102,23 +114,32 @@ def test_partition_via_api_raises_with_bad_response(request: FixtureRequest):
     partition_mock_.assert_called_once()
 
 
-@pytest.mark.skipif(skip_outside_ci, reason="Skipping test run outside of CI")
+@pytest.mark.skipif(not is_in_ci, reason="Skipping test run outside of CI")
 @pytest.mark.skipif(skip_not_on_main, reason="Skipping test run outside of main branch")
 def test_partition_via_api_with_no_strategy():
+    test_file = example_doc_path("pdf/loremipsum-flat.pdf")
     elements_no_strategy = partition_via_api(
-        filename=example_doc_path("layout-parser-paper-fast.pdf"),
+        filename=test_file,
         strategy="auto",
         api_key=get_api_key(),
         # The url has changed since the 06/24 API release while the sdk defaults to the old url
-        api_url="https://api.unstructuredapp.io/general/v0/general",
+        api_url=API_URL,
         skip_infer_table_types=["pdf"],
     )
     elements_hi_res = partition_via_api(
-        filename=example_doc_path("layout-parser-paper-fast.pdf"),
+        filename=test_file,
         strategy="hi_res",
         api_key=get_api_key(),
         # The url has changed since the 06/24 API release while the sdk defaults to the old url
-        api_url="https://api.unstructuredapp.io/general/v0/general",
+        api_url=API_URL,
+        skip_infer_table_types=["pdf"],
+    )
+    elements_fast_res = partition_via_api(
+        filename=test_file,
+        strategy="fast",
+        api_key=get_api_key(),
+        # The url has changed since the 06/24 API release while the sdk defaults to the old url
+        api_url=API_URL,
         skip_infer_table_types=["pdf"],
     )
 
@@ -126,49 +147,38 @@ def test_partition_via_api_with_no_strategy():
     # elements_hi_res[3].text =
     #     'LayoutParser: A Uniﬁed Toolkit for Deep Learning Based Document Image Analysis'
     # while elements_no_strategy[3].text = ']' (as of this writing)
-    assert elements_no_strategy[3].text != elements_hi_res[3].text
+    assert len(elements_no_strategy) == len(elements_hi_res)
+    assert len(elements_hi_res) != len(elements_fast_res)
+
+    # NOTE(crag): slightly out scope assertion, but avoid extra API call
+    assert elements_hi_res[0].metadata.coordinates is None
 
 
-@pytest.mark.skipif(skip_outside_ci, reason="Skipping test run outside of CI")
+@pytest.mark.skipif(not is_in_ci, reason="Skipping test run outside of CI")
 @pytest.mark.skipif(skip_not_on_main, reason="Skipping test run outside of main branch")
 def test_partition_via_api_with_image_hi_res_strategy_includes_coordinates():
     # coordinates not included by default to limit payload size
     elements = partition_via_api(
-        filename=example_doc_path("layout-parser-paper-fast.pdf"),
+        filename=example_doc_path("pdf/fake-memo.pdf"),
         strategy="hi_res",
         coordinates="true",
         api_key=get_api_key(),
-        # The url has changed since the 06/24 API release while the sdk defaults to the old url
-        api_url="https://api.unstructuredapp.io/general/v0/general",
+        api_url=API_URL,
     )
 
     assert elements[0].metadata.coordinates is not None
 
 
-@pytest.mark.skipif(skip_outside_ci, reason="Skipping test run outside of CI")
-@pytest.mark.skipif(skip_not_on_main, reason="Skipping test run outside of main branch")
-def test_partition_via_api_valid_request_data_kwargs():
-    elements = partition_via_api(
-        filename=example_doc_path("layout-parser-paper-fast.pdf"),
-        strategy="fast",
-        api_key=get_api_key(),
-        # The url has changed since the 06/24 API release while the sdk defaults to the old url
-        api_url="https://api.unstructuredapp.io/general/v0/general",
-    )
-
-    assert isinstance(elements, list)
-
-
-@pytest.mark.skipif(skip_outside_ci, reason="Skipping test run outside of CI")
+@pytest.mark.skipif(not is_in_ci, reason="Skipping test run outside of CI")
 @pytest.mark.skipif(skip_not_on_main, reason="Skipping test run outside of main branch")
 def test_partition_via_api_image_block_extraction():
     elements = partition_via_api(
-        filename=example_doc_path("embedded-images-tables.pdf"),
+        filename=example_doc_path("pdf/embedded-images-tables.pdf"),
         strategy="hi_res",
         extract_image_block_types=["image", "table"],
         api_key=get_api_key(),
         # The url has changed since the 06/24 API release while the sdk defaults to the old url
-        api_url="https://api.unstructuredapp.io/general/v0/general",
+        api_url=API_URL,
     )
     image_elements = [el for el in elements if el.category == ElementType.IMAGE]
     for el in image_elements:
@@ -178,6 +188,25 @@ def test_partition_via_api_image_block_extraction():
         assert isinstance(image_data, bytes)
 
 
+@pytest.mark.skipif(not is_in_ci, reason="Skipping test run outside of CI")
+@pytest.mark.skipif(skip_not_on_main, reason="Skipping test run outside of main branch")
+def test_partition_via_api_retries_config():
+    elements = partition_via_api(
+        filename=example_doc_path("pdf/embedded-images-tables.pdf"),
+        strategy="fast",
+        api_key=get_api_key(),
+        # The url has changed since the 06/24 API release while the sdk defaults to the old url
+        api_url=API_URL,
+        retries_initial_interval=5,
+        retries_max_interval=15,
+        retries_max_elapsed_time=100,
+        retries_connection_errors=True,
+        retries_exponent=1.5,
+    )
+
+    assert len(elements) > 0
+
+
 # Note(austin) - This test is way too noisy against the hosted api
 # def test_partition_via_api_invalid_request_data_kwargs():
 #     filename = os.path.join(DIRECTORY, "..", "..", "example-docs", "layout-parser-paper-fast.pdf")
@@ -185,6 +214,84 @@ def test_partition_via_api_image_block_extraction():
 #         partition_via_api(filename=filename, strategy="not_a_strategy")
 
 
+def test_retries_config_with_parameters_set():
+    sdk = Mock()
+    retries_config = get_retries_config(
+        retries_connection_errors=True,
+        retries_exponent=1.75,
+        retries_initial_interval=20,
+        retries_max_elapsed_time=1000,
+        retries_max_interval=100,
+        sdk=sdk,
+    )
+
+    assert retries_config.retry_connection_errors
+    assert retries_config.backoff.exponent == 1.75
+    assert retries_config.backoff.initial_interval == 20
+    assert retries_config.backoff.max_elapsed_time == 1000
+    assert retries_config.backoff.max_interval == 100
+
+
+def test_retries_config_none_parameters_return_empty_config():
+    sdk = Mock()
+    retries_config = get_retries_config(
+        retries_connection_errors=None,
+        retries_exponent=None,
+        retries_initial_interval=None,
+        retries_max_elapsed_time=None,
+        retries_max_interval=None,
+        sdk=sdk,
+    )
+
+    assert retries_config is None
+
+
+def test_retries_config_with_no_parameters_set():
+    retry_config = retries.RetryConfig(
+        "backoff", retries.BackoffStrategy(3000, 720000, 1.88, 1800000), True
+    )
+    sdk = Mock()
+    sdk.sdk_configuration.retry_config = retry_config
+    retries_config = get_retries_config(
+        retries_connection_errors=True,
+        retries_exponent=None,
+        retries_initial_interval=None,
+        retries_max_elapsed_time=None,
+        retries_max_interval=None,
+        sdk=sdk,
+    )
+
+    assert retries_config.retry_connection_errors
+    assert retries_config.backoff.exponent == 1.88
+    assert retries_config.backoff.initial_interval == 3000
+    assert retries_config.backoff.max_elapsed_time == 1800000
+    assert retries_config.backoff.max_interval == 720000
+
+
+def test_retries_config_cascade():
+    # notice max_interval is set to 0 which is incorrect - so the DEFAULT_RETRIES_MAX_INTERVAL_SEC
+    # should be used
+    retry_config = retries.RetryConfig(
+        "backoff", retries.BackoffStrategy(3000, 0, 1.88, None), True
+    )
+    sdk = Mock()
+    sdk.sdk_configuration.retry_config = retry_config
+    retries_config = get_retries_config(
+        retries_connection_errors=False,
+        retries_exponent=1.75,
+        retries_initial_interval=20,
+        retries_max_elapsed_time=None,
+        retries_max_interval=None,
+        sdk=sdk,
+    )
+
+    assert not retries_config.retry_connection_errors
+    assert retries_config.backoff.exponent == 1.75
+    assert retries_config.backoff.initial_interval == 20
+    assert retries_config.backoff.max_elapsed_time == DEFAULT_RETRIES_MAX_ELAPSED_TIME_SEC
+    assert retries_config.backoff.max_interval == DEFAULT_RETRIES_MAX_INTERVAL_SEC
+
+
 def test_partition_multiple_via_api_with_single_filename(request: FixtureRequest):
     partition_mock_ = method_mock(
         request, requests, "post", return_value=FakeResponse(status_code=200)
@@ -353,29 +460,31 @@ def get_api_key():
     return api_key
 
 
-@pytest.mark.skipif(skip_outside_ci, reason="Skipping test run outside of CI")
+@pytest.mark.skipif(not is_in_ci, reason="Skipping test run outside of CI")
 @pytest.mark.skipif(skip_not_on_main, reason="Skipping test run outside of main branch")
 def test_partition_multiple_via_api_valid_request_data_kwargs():
     filenames = [
-        example_doc_path("layout-parser-paper-fast.pdf"),
-        example_doc_path("layout-parser-paper-fast.jpg"),
+        example_doc_path("fake-text.txt"),
+        example_doc_path("fake-email.txt"),
     ]
 
-    elements = partition_multiple_via_api(
+    list_of_lists_of_elements = partition_multiple_via_api(
         filenames=filenames,
-        strategy="auto",
+        strategy="fast",
         api_key=get_api_key(),
-        # The url has changed since the 06/24 API release while the sdk defaults to the old url
-        api_url="https://api.unstructuredapp.io/general/v0/general",
+        api_url=API_URL,
     )
-    assert isinstance(elements, list)
+    # assert there is a list of elements for each file
+    assert len(list_of_lists_of_elements) == 2
+    assert isinstance(list_of_lists_of_elements[0], list)
+    assert isinstance(list_of_lists_of_elements[1], list)
 
 
-@pytest.mark.skipif(skip_outside_ci, reason="Skipping test run outside of CI")
+@pytest.mark.skipif(not is_in_ci, reason="Skipping test run outside of CI")
 def test_partition_multiple_via_api_invalid_request_data_kwargs():
     filenames = [
-        example_doc_path("layout-parser-paper-fast.pdf"),
-        example_doc_path("layout-parser-paper-fast.jpg"),
+        example_doc_path("pdf/layout-parser-paper-fast.pdf"),
+        example_doc_path("img/layout-parser-paper-fast.jpg"),
     ]
     with pytest.raises(ValueError):
         partition_multiple_via_api(
@@ -383,7 +492,7 @@ def test_partition_multiple_via_api_invalid_request_data_kwargs():
             strategy="not_a_strategy",
             api_key=get_api_key(),
             # The url has changed since the 06/24 API release while the sdk defaults to the old url
-            api_url="https://api.unstructuredapp.io/general/v0/general",
+            api_url=API_URL,
         )
 
 
@@ -484,36 +593,39 @@ def expected_call_():
         file_bytes = f.read()
     return [
         ANY,
-        PartitionParameters(
-            files=shared.Files(
-                content=file_bytes,
-                file_name=example_doc_path("eml/fake-email.eml"),
-            ),
-            chunking_strategy=None,
-            combine_under_n_chars=None,
-            coordinates=False,
-            encoding=None,
-            extract_image_block_types=None,
-            gz_uncompressed_content_type=None,
-            hi_res_model_name=None,
-            include_orig_elements=None,
-            include_page_breaks=False,
-            languages=None,
-            max_characters=None,
-            multipage_sections=True,
-            new_after_n_chars=None,
-            ocr_languages=None,
-            output_format=shared.OutputFormat.APPLICATION_JSON,
-            overlap=0,
-            overlap_all=False,
-            pdf_infer_table_structure=True,
-            similarity_threshold=None,
-            skip_infer_table_types=None,
-            split_pdf_concurrency_level=5,
-            split_pdf_page=True,
-            starting_page_number=None,
-            strategy=shared.Strategy.AUTO,
-            unique_element_ids=False,
-            xml_keep_tags=False,
+        PartitionRequest(
+            partition_parameters=PartitionParameters(
+                files=shared.Files(
+                    content=file_bytes,
+                    file_name=example_doc_path("eml/fake-email.eml"),
+                ),
+                chunking_strategy=None,
+                combine_under_n_chars=None,
+                coordinates=False,
+                encoding=None,
+                extract_image_block_types=None,
+                gz_uncompressed_content_type=None,
+                hi_res_model_name=None,
+                include_orig_elements=None,
+                include_page_breaks=False,
+                languages=None,
+                max_characters=None,
+                multipage_sections=True,
+                new_after_n_chars=None,
+                ocr_languages=None,
+                output_format=shared.OutputFormat.APPLICATION_JSON,
+                overlap=0,
+                overlap_all=False,
+                pdf_infer_table_structure=True,
+                similarity_threshold=None,
+                skip_infer_table_types=None,
+                split_pdf_concurrency_level=5,
+                split_pdf_page=True,
+                starting_page_number=None,
+                strategy=shared.Strategy.HI_RES,
+                unique_element_ids=False,
+                xml_keep_tags=False,
+            )
         ),
+        None,  # retries kwarg
     ]
