@@ -150,6 +150,11 @@ class ENVConfig:
         """
         return self._get_float("EMBEDDED_TEXT_AGGREGATION_SUBREGION_THRESHOLD", 0.99)
 
+    @property
+    def EMBEDDED_TEXT_SAME_REGION_THRESHOLD(self) -> float:
+        """threshold to consider the bounding boxes of two embedded images as the same region"""
+        return self._get_float("EMBEDDED_TEXT_SAME_REGION_THRESHOLD", 0.9)
+
     @property
     def PDF_ANNOTATION_THRESHOLD(self) -> float:
         """The threshold value (between 0.0 and 1.0) that determines the minimum overlap required
